
import os
import sys
import pyutilib.subprocess
import glob
import optparse

if sys.platform.startswith('win'):
    platform='win'
else:
    platform='linux'

def run(argv):
    parser = optparse.OptionParser(usage='svn_update [OPTIONS] <dirs>')

    parser.add_option('-v','--verbose',
        action='store_true',
        dest='verbose',
        default=False,
        help='Verbose output')
    parser.add_option('-p','--package',
        action='store',
        dest='pkg',
        default='pyutilib',
        help='Limit the coverage to this package')

    options, args = parser.parse_args(argv)

    if len(args) == 1:
        parser.print_help()
        sys.exit(1)

    if options.pkg != "":
        cpkg=' --cover-package='+options.pkg
    else:
        cpkg=''
    if options.verbose:
        vflag=' -v'
    else:
        vflag=''

    os.environ['COVERAGE_FILE'] = os.getcwd()+os.sep+'.coverage'

    dirs=set()
    dirs.add( os.getcwd() )
    for arg in args[1:]:
        for dir in glob.glob(arg+'*'):
            dirs.add(dir)

    if platform == 'win':
	srcdirs=[]
        for dir in glob.glob('*'):
	    if os.path.isdir(dir):
                srcdirs.append(os.path.abspath(dir))
	os.environ['PYTHONPATH']=os.pathsep.join(srcdirs)
        cwd = os.path.dirname(os.getcwd())
        cmd =  os.sep.join([cwd,'Scripts','python.exe'])+' '+os.sep.join([cwd,'Scripts','nosetests-script.py'])+' --with-coverage --cover-erase'+vflag+cpkg+' --with-xunit --xunit-file=TEST-pyutilib.xml '+ " ".join(list(dirs))
    else:
        cmd = os.path.dirname(os.getcwd())+os.sep+'bin'+os.sep+'nosetests --with-coverage --cover-erase'+vflag+cpkg+' --with-xunit --xunit-file=TEST-pyutilib.xml '+ " ".join(list(dirs))
    print "Running... "+cmd
    pyutilib.subprocess.run(cmd, tee=True)


def runPyUtilibTests():
    parser = optparse.OptionParser(usage='test.pyutilib [options] <dirs>')

    parser.add_option('-d','--dir',
        action='store',
        dest='dir',
        default=None,
        help='Top-level source directory where the tests are applied.')

    options, args = parser.parse_args(sys.argv)

    #if len(args) == 1:
        #parser.print_help()
        #sys.exit(1)

    if options.dir is None:
        os.chdir( os.path.dirname(os.path.dirname(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))) )
    else:
        os.chdir( options.dir )

    print "Running tests in directory",os.getcwd()
    options=[]
    if len(args) == 1:
        dirs=['pyutilib']
    else:
        dirs=[]
        for dir in args:
            if dir.startswith('-'):
                options.append(dir)
            elif dir.startswith('pyutilib'):
                dirs.append(dir)
            else:
                dirs.append('pyutilib.'+dir)
        if len(dirs) == 0:
            dirs = ['pyutilib']
    pyutilib.dev.runtests.run(['runtests']+options+['-p','pyutilib']+dirs)

